macro "merge 3 channel images to blue green red stack"{
// "Batch Create 3 colour stack" adapted from "Batch RGB merge" 
// Source: http://rsb.info.nih.gov/ij/macros/Batch_RGB_Merge.txt
// Adaptation by Dale Moulding, UCL Institute of Child Health Imaging Facilty, 2015
 
// It is assumed the output stack is ordered as c1=blue, c2=green, c3=red
// this can be changed in the script where marked below.

// The first dialog box reuqires you to state the suffix for each channel colour.

// A sample image set, courtesy of Mikael Bjorklund, is available at:
// http://rsb.info.nih.gov/ij/macros/images/DrosophilaCells.zip
// It consists of three images of Drosophila S2 cells,
// each with three channels (d0=blue, d1=red and d2=green  
// as indicated by the end of the filename. The staining is
// standard Hoechst, phalloidin, tubulin.

  Dialog.create("Batch create 3 colour stack");
  Dialog.addString("Blue Suffix:", "Dapi");
  Dialog.addString("Green Suffix:", "Actin");
  Dialog.addString("Red Suffix:", "Tub");

  Dialog.show();
  blueSuffix = Dialog.getString() + ".";
  greenSuffix = Dialog.getString() + ".";
  redSuffix = Dialog.getString() + ".";
  batchConvert();
  x=nImages();
  print(x+" three-channel composite images produced");
  exit;

  function batchConvert() {
      dir1 = getDirectory("Choose Source Directory ");
      dir2 = getDirectory("Choose Destination Directory ");
      list = getFileList(dir1);
      setBatchMode(true);
      n = list.length;
      if ((n%3)!=0)
         exit("The number of files must be a multiple of 3");
      stack = 0;
      first = 0;
      for (i=0; i<n/3; i++) {
          showProgress(i+1, n/3);
          red="?"; green="?"; blue="?";
          for (j=first; j<first+3; j++) {
              if (indexOf(list[j], redSuffix)!=-1)
                  red = list[j];
              if (indexOf(list[j], greenSuffix)!=-1)
                  green = list[j];
              if (indexOf(list[j], blueSuffix)!=-1)
                  blue = list[j];
          }
          open(dir1 +blue);
          open(dir1 +green);
          open(dir1 +red);
          run("Merge Channels...", "c1=["+blue+"] c2=["+green+"] c3=["+red+"] create");
          Stack.setChannel(1); //choose the colour of the first channel:
          run("Blue");
          Stack.setChannel(2); //choose the colour of the second channel:
          run("Green");
          Stack.setChannel(3); //choose the colour of the third channel:
          run("Red");
          index = indexOf(red, redSuffix);
          name = substring(red, 0, index);
          saveAs("tiff", dir2+name);
          first += 3;
      }
  }
}
